UIX — Kivy v1.0.1-dev documentation

# UIX

The kivy.uix contain all the class for create and arrange Widgets. A widget is an element of a graphical user interface.

If you don’t know anything about Widget, you can start to read the `Widget` class and usage.

If you need to arrange widget on the screen, start reading the `Layout` class.

- Anchor layout
- Box Layout
- Button
- Camera
- Float Layout
- Image
  - Asynchronous loading
  - Alignement
- Label
- Layout
  - Understanding size_hint property in Widget
- Scatter
  - Usage
  - Control interactions
  - Automatic bring to front
  - Scale limitation
- Slider
- Toggle button
- Video
- Widget class
  - Usage of properties